summaryrefslogtreecommitdiff
path: root/guix
diff options
context:
space:
mode:
authorMark H Weaver <mhw@netris.org>2014-08-28 14:22:15 -0400
committerMark H Weaver <mhw@netris.org>2014-08-28 14:22:15 -0400
commitc00a9fbfef75d2fc08485f8158ec331bfa99d5ec (patch)
tree4737817ee787c4ec8222ea13d3cfecb2ac98b673 /guix
parent83291101c39c1cd1bf472280c24ad68d94248c2e (diff)
parentdd16424466196616b99c13526537a89aaee27f88 (diff)
Merge branch 'master' into core-updates
Conflicts: gnu/packages/base.scm
Diffstat (limited to 'guix')
-rw-r--r--guix/build-system/cmake.scm4
-rw-r--r--guix/build-system/gnu.scm11
-rw-r--r--guix/build-system/perl.scm8
-rw-r--r--guix/build-system/python.scm4
-rw-r--r--guix/build-system/trivial.scm4
-rw-r--r--guix/build/linux-initrd.scm9
-rw-r--r--guix/download.scm4
-rw-r--r--guix/gexp.scm2
-rw-r--r--guix/git-download.scm2
-rw-r--r--guix/monads.scm2
-rw-r--r--guix/packages.scm2
-rw-r--r--guix/profiles.scm10
-rw-r--r--guix/scripts/package.scm12
-rw-r--r--guix/scripts/pull.scm5
-rw-r--r--guix/scripts/refresh.scm2
-rw-r--r--guix/svn-download.scm2
16 files changed, 49 insertions, 34 deletions
diff --git a/guix/build-system/cmake.scm b/guix/build-system/cmake.scm
index 8c9a32c8ab..0fc7b62c1b 100644
--- a/guix/build-system/cmake.scm
+++ b/guix/build-system/cmake.scm
@@ -1,5 +1,5 @@
;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
;;; Copyright © 2013 Cyril Roelandt <tipecaml@gmail.com>
;;;
;;; This file is part of GNU Guix.
@@ -99,7 +99,7 @@ provides a 'CMakeLists.txt' file as its build system."
((and (? string?) (? derivation-path?))
guile)
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
diff --git a/guix/build-system/perl.scm b/guix/build-system/perl.scm
index 56954911cb..993cd7448e 100644
--- a/guix/build-system/perl.scm
+++ b/guix/build-system/perl.scm
@@ -1,5 +1,5 @@
;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
;;;
;;; This file is part of GNU Guix.
;;;
@@ -47,6 +47,8 @@
(perl (default-perl))
(search-paths '())
(tests? #t)
+ (parallel-build? #t)
+ (parallel-tests? #t)
(make-maker-flags ''())
(phases '(@ (guix build perl-build-system)
%standard-phases))
@@ -79,6 +81,8 @@ provides a `Makefile.PL' file as its build system."
#:system ,system
#:test-target "test"
#:tests? ,tests?
+ #:parallel-build? ,parallel-build?
+ #:parallel-tests? ,parallel-tests?
#:outputs %outputs
#:inputs %build-inputs)))
@@ -89,7 +93,7 @@ provides a `Makefile.PL' file as its build system."
((and (? string?) (? derivation-path?))
guile)
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
diff --git a/guix/build-system/python.scm b/guix/build-system/python.scm
index 7e26864653..dfb8b4a137 100644
--- a/guix/build-system/python.scm
+++ b/guix/build-system/python.scm
@@ -1,5 +1,5 @@
;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
;;; Copyright © 2013 Andreas Enge <andreas@enge.fr>
;;; Copyright © 2013 Nikita Karetnikov <nikita@karetnikov.org>
;;;
@@ -141,7 +141,7 @@ provides a 'setup.py' file as its build system."
((and (? string?) (? derivation-path?))
guile)
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
diff --git a/guix/build-system/trivial.scm b/guix/build-system/trivial.scm
index 5576d596da..475e8563e5 100644
--- a/guix/build-system/trivial.scm
+++ b/guix/build-system/trivial.scm
@@ -1,5 +1,5 @@
;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2012, 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <ludo@gnu.org>
;;;
;;; This file is part of GNU Guix.
;;;
@@ -32,7 +32,7 @@
((and (? string?) (? derivation-path?))
guile)
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
diff --git a/guix/build/linux-initrd.scm b/guix/build/linux-initrd.scm
index bce289987b..d37da9a6ff 100644
--- a/guix/build/linux-initrd.scm
+++ b/guix/build/linux-initrd.scm
@@ -229,8 +229,11 @@ the following:
• 'any', in which case SPEC can be anything.
"
(define max-trials
- ;; Number of times we retry partition label resolution.
- 7)
+ ;; Number of times we retry partition label resolution, 1 second per
+ ;; trial. Note: somebody reported a delay of 16 seconds (!) before their
+ ;; USB key would be detected by the kernel, so we must wait for at least
+ ;; this long.
+ 20)
(define canonical-title
;; The realm of canonicalization.
@@ -254,6 +257,8 @@ the following:
(if (> count max-trials)
(error "failed to resolve partition label" spec)
(begin
+ (format #t "waiting for partition '~a' to appear...~%"
+ spec)
(sleep 1)
(loop (+ 1 count))))))))
;; TODO: Add support for UUIDs.
diff --git a/guix/download.scm b/guix/download.scm
index 92d08fc2bd..c0a7e8c23a 100644
--- a/guix/download.scm
+++ b/guix/download.scm
@@ -205,8 +205,8 @@ must be a list of symbol/URL-list pairs."
(define guile-for-build
(package-derivation store
(or guile
- (let ((distro
- (resolve-interface '(gnu packages base))))
+ (let ((distro (resolve-interface
+ '(gnu packages commencement))))
(module-ref distro 'guile-final)))
system))
diff --git a/guix/gexp.scm b/guix/gexp.scm
index 6d1f328aef..e31324e101 100644
--- a/guix/gexp.scm
+++ b/guix/gexp.scm
@@ -429,7 +429,7 @@ package/derivation references."
(define (default-guile)
;; Lazily resolve 'guile-final'. This module must not refer to (gnu …)
;; modules directly, to avoid circular dependencies, hence this hack.
- (module-ref (resolve-interface '(gnu packages base))
+ (module-ref (resolve-interface '(gnu packages commencement))
'guile-final))
(define* (gexp->script name exp
diff --git a/guix/git-download.scm b/guix/git-download.scm
index 5691e8a870..a8b7882c9f 100644
--- a/guix/git-download.scm
+++ b/guix/git-download.scm
@@ -65,7 +65,7 @@ type HASH-ALGO (a symbol). Use NAME as the file name, or a generic name if
((? package?)
(package-derivation store guile system))
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
diff --git a/guix/monads.scm b/guix/monads.scm
index c714941a0c..2ab3fb94f0 100644
--- a/guix/monads.scm
+++ b/guix/monads.scm
@@ -444,7 +444,7 @@ connection."
(define (default-guile)
;; Lazily resolve 'guile-final'. This module must not refer to (gnu …)
;; modules directly, to avoid circular dependencies, hence this hack.
- (module-ref (resolve-interface '(gnu packages base))
+ (module-ref (resolve-interface '(gnu packages commencement))
'guile-final))
(parameterize ((%guile-for-build (or guile-for-build
diff --git a/guix/packages.scm b/guix/packages.scm
index 1939373f35..b4fc026dbb 100644
--- a/guix/packages.scm
+++ b/guix/packages.scm
@@ -291,7 +291,7 @@ corresponds to the arguments expected by `set-path-environment-variable'."
(define (default-guile)
"Return the default Guile package for SYSTEM."
- (let ((distro (resolve-interface '(gnu packages base))))
+ (let ((distro (resolve-interface '(gnu packages commencement))))
(module-ref distro 'guile-final)))
(define* (patch-and-repack store source patches
diff --git a/guix/profiles.scm b/guix/profiles.scm
index a2c73fd4cd..55c3b6e768 100644
--- a/guix/profiles.scm
+++ b/guix/profiles.scm
@@ -376,10 +376,11 @@ or
(define (info-dir-file manifest)
"Return a derivation that builds the 'dir' file for all the entries of
MANIFEST."
- (define texinfo
- ;; Lazy reference.
- (module-ref (resolve-interface '(gnu packages texinfo))
- 'texinfo))
+ (define texinfo ;lazy reference
+ (module-ref (resolve-interface '(gnu packages texinfo)) 'texinfo))
+ (define gzip ;lazy reference
+ (module-ref (resolve-interface '(gnu packages compression)) 'gzip))
+
(define build
#~(begin
(use-modules (guix build utils)
@@ -396,6 +397,7 @@ MANIFEST."
(or (scandir infodir info-file?) '()))))
(define (install-info info)
+ (setenv "PATH" (string-append #+gzip "/bin")) ;for info.gz files
(zero?
(system* (string-append #+texinfo "/bin/install-info")
info (string-append #$output "/share/info/dir"))))
diff --git a/guix/scripts/package.scm b/guix/scripts/package.scm
index fb285c5e67..6ecf37e1a6 100644
--- a/guix/scripts/package.scm
+++ b/guix/scripts/package.scm
@@ -39,7 +39,8 @@
#:use-module (srfi srfi-26)
#:use-module (srfi srfi-37)
#:use-module (gnu packages)
- #:use-module ((gnu packages base) #:select (guile-final))
+ #:use-module (gnu packages base)
+ #:use-module (gnu packages guile)
#:use-module ((gnu packages bootstrap) #:select (%bootstrap-guile))
#:export (specification->package+output
guix-package))
@@ -914,8 +915,9 @@ more information.~%"))
(set-build-options-from-command-line (%store) opts)
(parameterize ((%guile-for-build
- (package-derivation (%store)
- (if (assoc-ref opts 'bootstrap?)
- %bootstrap-guile
- guile-final))))
+ (package-derivation
+ (%store)
+ (if (assoc-ref opts 'bootstrap?)
+ %bootstrap-guile
+ (canonical-package guile-2.0)))))
(process-actions opts)))))))
diff --git a/guix/scripts/pull.scm b/guix/scripts/pull.scm
index 00bea1707d..c2bf536e86 100644
--- a/guix/scripts/pull.scm
+++ b/guix/scripts/pull.scm
@@ -1,5 +1,5 @@
;;; GNU Guix --- Functional package management for GNU
-;;; Copyright © 2013 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2013, 2014 Ludovic Courtès <ludo@gnu.org>
;;;
;;; This file is part of GNU Guix.
;;;
@@ -24,6 +24,7 @@
#:use-module (guix derivations)
#:use-module (guix download)
#:use-module (gnu packages base)
+ #:use-module (gnu packages guile)
#:use-module ((gnu packages bootstrap)
#:select (%bootstrap-guile))
#:use-module (gnu packages compression)
@@ -128,7 +129,7 @@ Download and deploy the latest version of Guix.\n"))
(package-derivation store
(if (assoc-ref opts 'bootstrap?)
%bootstrap-guile
- guile-final)))
+ (canonical-package guile-2.0))))
(current-build-output-port
(if (assoc-ref opts 'verbose?)
(current-error-port)
diff --git a/guix/scripts/refresh.scm b/guix/scripts/refresh.scm
index a91ea69b1f..d31e6d4897 100644
--- a/guix/scripts/refresh.scm
+++ b/guix/scripts/refresh.scm
@@ -27,7 +27,7 @@
#:use-module (guix gnu-maintenance)
#:use-module (guix gnupg)
#:use-module (gnu packages)
- #:use-module ((gnu packages base) #:select (%final-inputs))
+ #:use-module ((gnu packages commencement) #:select (%final-inputs))
#:use-module (ice-9 match)
#:use-module (ice-9 regex)
#:use-module (ice-9 vlist)
diff --git a/guix/svn-download.scm b/guix/svn-download.scm
index cb4d9dcc11..31dd1a90e8 100644
--- a/guix/svn-download.scm
+++ b/guix/svn-download.scm
@@ -61,7 +61,7 @@ type HASH-ALGO (a symbol). Use NAME as the file name, or a generic name if
((? package?)
(package-derivation store guile system))
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
diff --git a/guix/build-system/gnu.scm b/guix/build-system/gnu.scm
index b2b184db34..7c9b6ca398 100644
--- a/guix/build-system/gnu.scm
+++ b/guix/build-system/gnu.scm
@@ -209,8 +209,8 @@ listed in REFS."
"Return the list of (NAME PACKAGE OUTPUT) or (NAME PACKAGE) tuples of
standard packages used as implicit inputs of the GNU build system."
- ;; Resolve (gnu packages base) lazily to hide circular dependency.
- (let ((distro (resolve-module '(gnu packages base))))
+ ;; Resolve (gnu packages commencement) lazily to hide circular dependency.
+ (let ((distro (resolve-module '(gnu packages commencement))))
(module-ref distro '%final-inputs)))
(define* (inputs-search-paths inputs
@@ -268,7 +268,8 @@ System: GCC, GNU Make, Bash, Coreutils, etc."
(out-of-source? #f)
(tests? #t)
(test-target "check")
- (parallel-build? #t) (parallel-tests? #t)
+ (parallel-build? #t)
+ (parallel-tests? #t)
(patch-shebangs? #t)
(strip-binaries? #t)
(strip-flags ''("--strip-debug"))
@@ -346,7 +347,7 @@ are allowed to refer to."
;; ((and (? string?) (? derivation-path?))
;; guile)
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))
@@ -532,7 +533,7 @@ platform."
;; ((and (? string?) (? derivation-path?))
;; guile)
(#f ; the default
- (let* ((distro (resolve-interface '(gnu packages base)))
+ (let* ((distro (resolve-interface '(gnu packages commencement)))
(guile (module-ref distro 'guile-final)))
(package-derivation store guile system)))))